@@ -1,19 +1,7 @@
-/* This file is part of Step.
-   Copyright (C) 2007 Vladimir Kuznetsov <ks.vladimir@gmail.com>
+/*.
+    SPDX-FileCopyrightText: 2007 Vladimir Kuznetsov <ks.vladimir@gmail.com>
 
-   Step is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
-   (at your option) any later version.
-
-   Step is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with Step; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef STEP_JOINTGRAPHICS_H
@@ -29,7 +17,7 @@ public:
     AnchorCreator(const QString& className, WorldModel* worldModel, WorldScene* worldScene)
         : AttachableItemCreator(className, worldModel, worldScene, WorldScene::SnapRigidBody |
                         WorldScene::SnapParticle | WorldScene::SnapOnCenter |
-                        WorldScene::SnapSetPosition | WorldScene::SnapSetAngle, 0) {}
+                        WorldScene::SnapSetPosition | WorldScene::SnapSetAngle, nullptr) {}
 };
 
 class AnchorGraphicsItem : public StepGraphicsItem
@@ -55,7 +43,7 @@ class PinCreator: public AttachableItemCreator
 public:
     PinCreator(const QString& className, WorldModel* worldModel, WorldScene* worldScene)
         : AttachableItemCreator(className, worldModel, worldScene, WorldScene::SnapRigidBody |
-                            WorldScene::SnapSetPosition | WorldScene::SnapSetLocalPosition, 0) {}
+                            WorldScene::SnapSetPosition | WorldScene::SnapSetLocalPosition, nullptr) {}
 };
 
 class PinGraphicsItem: public StepGraphicsItem
@@ -82,7 +70,7 @@ public:
     StickCreator(const QString& className, WorldModel* worldModel, WorldScene* worldScene)
                 : AttachableItemCreator(className, worldModel, worldScene,
                         WorldScene::SnapRigidBody | WorldScene::SnapParticle |
-                        WorldScene::SnapSetLocalPosition, 0, true) {}
+                        WorldScene::SnapSetLocalPosition, nullptr, true) {}
 };
 
 class StickHandlerGraphicsItem: public StepGraphicsItem
