@@ -1,20 +1,8 @@
-/* This file is part of Step.
-   Copyright (C) 2007 Vladimir Kuznetsov <ks.vladimir@gmail.com>
-   Copyright (C) 2014 Inge Wallin        <inge@lysator.liu.se>
+/*.
+    SPDX-FileCopyrightText: 2007 Vladimir Kuznetsov <ks.vladimir@gmail.com>
+    SPDX-FileCopyrightText: 2014 Inge Wallin <inge@lysator.liu.se>
 
-   Step is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
-   (at your option) any later version.
-
-   Step is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with Step; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "toolgraphics.h"
@@ -130,7 +118,7 @@ void WidgetVertexHandlerGraphicsItem::setValue(const StepCore::Vector2d& value)
 }
 
 WidgetGraphicsItem::WidgetGraphicsItem(StepCore::Item* item, WorldModel* worldModel)
-    : StepGraphicsItem(item, worldModel), _centralWidget(0)
+    : StepGraphicsItem(item, worldModel), _centralWidget(nullptr)
 {
     setFlag(QGraphicsItem::ItemIsSelectable);
     setFlag(QGraphicsItem::ItemIsMovable);
@@ -170,7 +158,7 @@ OnHoverHandlerGraphicsItem* WidgetGraphicsItem::createOnHoverHandler(const QPoin
     if(num >= 0)
         return new WidgetVertexHandlerGraphicsItem(_item, _worldModel, this, num);
 
-    return 0;
+    return nullptr;
 }
 
 // XXX: ???
@@ -310,15 +298,15 @@ void NoteTextEdit::focusOutEvent(QFocusEvent *event)
 StepCore::NoteFormula* NoteTextEdit::formulaAt(const QPoint& pos)
 {
     int p = document()->documentLayout()->hitTest(pos, Qt::ExactHit);
-    if(p < 0) return NULL;
+    if(p < 0) return nullptr;
 
     QTextCursor cursor(document());
     cursor.setPosition(p);
-    if(cursor.atEnd()) return NULL;
+    if(cursor.atEnd()) return nullptr;
     cursor.setPosition(p+1);
 
     QTextFormat format = cursor.charFormat();
-    if(!format.isImageFormat()) return NULL;
+    if(!format.isImageFormat()) return nullptr;
     QString image = format.toImageFormat().name();
 
     StepCore::Item* item = _noteItem->note()->childItem(image);
@@ -328,7 +316,7 @@ StepCore::NoteFormula* NoteTextEdit::formulaAt(const QPoint& pos)
     }
 
     if(!item || !item->metaObject()->inherits<StepCore::NoteFormula>())
-        return NULL;
+        return nullptr;
 
     return static_cast<StepCore::NoteFormula*>(item);
 }
@@ -341,7 +329,7 @@ void NoteTextEdit::mousePressEvent(QMouseEvent *e)
 
 void NoteTextEdit::mouseMoveEvent(QMouseEvent *e)
 {
-    if(formulaAt(e->pos()) != NULL) {
+    if(formulaAt(e->pos()) != nullptr) {
         viewport()->setCursor(Qt::PointingHandCursor);
     } else {
         viewport()->setCursor(Qt::IBeamCursor);
@@ -367,7 +355,7 @@ void NoteTextEdit::mouseReleaseEvent(QMouseEvent *e)
 NoteGraphicsItem::NoteGraphicsItem(StepCore::Item* item, WorldModel* worldModel)
     : WidgetGraphicsItem(item, worldModel)
 {
-    Q_ASSERT(dynamic_cast<StepCore::Note*>(_item) != NULL);
+    Q_ASSERT(dynamic_cast<StepCore::Note*>(_item) != nullptr);
     setFlag(QGraphicsItem::ItemIsSelectable);
     setFlag(QGraphicsItem::ItemIsMovable);
     setAcceptHoverEvents(true);
@@ -419,12 +407,12 @@ NoteGraphicsItem::NoteGraphicsItem(StepCore::Item* item, WorldModel* worldModel)
     _actionFont = new KFontAction(i18n("&Font"), _toolBar);
     _actionFontSize = new KFontSizeAction(i18n("Font &Size"), _toolBar);
 
-    _actionInsertImage = new QAction(QIcon::fromTheme(QStringLiteral("insert-image")), i18n("Insert &Image"), _toolBar);
+    _actionInsertImage = new QAction(QIcon::fromTheme(QStringLiteral("insert-image")), i18n("Insert &Image..."), _toolBar);
 #ifdef __GNUC__
 #warning Select right icon here
 #endif
     _actionInsertFormula = new QAction(QIcon::fromTheme(QStringLiteral("application-vnd.oasis.opendocument.formula")),
-                                    i18n("Insert &Formula"), _toolBar);
+                                    i18n("Insert &Formula..."), _toolBar);
 
     connect(_actionColor, &QAction::triggered, this, &NoteGraphicsItem::formatColor);
     connect(_actionBold, &QAction::triggered, this, &NoteGraphicsItem::formatBold);
@@ -477,7 +465,7 @@ NoteGraphicsItem::NoteGraphicsItem(StepCore::Item* item, WorldModel* worldModel)
     QComboBox* font = qobject_cast<QComboBox*>(_toolBar->widgetForAction(_actionFont));
     if(font) {
         font->setMinimumContentsLength(5);
-        font->setSizeAdjustPolicy(QComboBox::AdjustToMinimumContentsLength);
+        font->setSizeAdjustPolicy(QComboBox::AdjustToContents);
         font->installEventFilter(this);
         font->setToolTip(_actionFont->toolTip());
     }
@@ -485,7 +473,7 @@ NoteGraphicsItem::NoteGraphicsItem(StepCore::Item* item, WorldModel* worldModel)
     QComboBox* fontSize = qobject_cast<QComboBox*>(_toolBar->widgetForAction(_actionFontSize));
     if(fontSize) {
         fontSize->setMinimumContentsLength(2);
-        fontSize->setSizeAdjustPolicy(QComboBox::AdjustToMinimumContentsLength);
+        fontSize->setSizeAdjustPolicy(QComboBox::AdjustToContents);
         fontSize->installEventFilter(this);
         fontSize->setToolTip(_actionFontSize->toolTip());
     }
@@ -526,7 +514,7 @@ bool NoteGraphicsItem::eventFilter(QObject* obj, QEvent* event)
             static_cast<QFocusEvent*>(event)->reason() != Qt::PopupFocusReason) {
 
         QObject* f = QApplication::focusWidget();
-        if(f == obj) f = NULL;
+        if(f == obj) f = nullptr;
         while(f && f != _widget) f = f->parent();
 
         if(!f) {
@@ -640,7 +628,7 @@ void NoteGraphicsItem::cursorPositionChanged()
 
 void NoteGraphicsItem::insertImage()
 {
-    QUrl url = QFileDialog::getOpenFileUrl(_widget, i18n("Open Image File"), QUrl(), i18n("Images (*.png *.jpg *.jpeg)"));
+    QUrl url = QFileDialog::getOpenFileUrl(_widget, i18nc("@title:window", "Open Image File"), QUrl(), i18n("Images (*.png *.jpg *.jpeg)"));
     if(url.isEmpty()) return;
 
     QTemporaryFile tempFile;
@@ -665,7 +653,7 @@ void NoteGraphicsItem::insertImage()
     QString imgName;
     for(int n=0;; ++n) {
         imgName = QStringLiteral("img:%1").arg(n);
-        if(note()->childItem(imgName) != NULL) continue;
+        if(note()->childItem(imgName) != nullptr) continue;
         bool found = false;
         foreach(StepCore::Item* item, _newItems)
             if(item->name() == imgName) { found = true; break; }
@@ -682,7 +670,7 @@ void NoteGraphicsItem::insertFormula()
     QString imgName;
     for(int n=0;; ++n) {
         imgName = QStringLiteral("fml:%1").arg(n);
-        if(note()->childItem(imgName) != NULL) continue;
+        if(note()->childItem(imgName) != nullptr) continue;
         bool found = false;
         foreach(StepCore::Item* item, _newItems)
             if(item->name() == imgName) { found = true; break; }
@@ -702,14 +690,14 @@ void NoteGraphicsItem::insertFormula()
 bool NoteGraphicsItem::editFormula(StepCore::NoteFormula* formula)
 {
     if(!LatexFormula::isLatexInstalled()) {
-        KMessageBox::sorry(_widget, i18n("Cannot find latex installation. "
+        KMessageBox::error(_widget, i18n("Cannot find latex installation. "
                     "You need 'latex', 'dvips' and 'gs' executables installed and accessible from $PATH"));
         return false;
     }
 
     bool ok;
-    QString code = QInputDialog::getMultiLineText(_widget, i18n("LaTex Formula - Step"),
-                i18n("Enter LaTeX formula string"), QString(formula->code()), &ok);
+    QString code = QInputDialog::getMultiLineText(_widget, i18nc("@title:window", "LaTex Formula - Step"),
+                i18n("Enter LaTeX formula string:"), QString(formula->code()), &ok);
     if(!ok) return false;
 
     QByteArray image;
@@ -777,7 +765,7 @@ void NoteGraphicsItem::worldDataChanged(bool dynamicOnly)
 
 ////////////////////////////////////////////////////
 DataSourceWidget::DataSourceWidget(QWidget* parent)
-    : QWidget(parent), _worldModel(0)
+    : QWidget(parent), _worldModel(nullptr)
 {
     _skipReadOnly = false;
     
@@ -798,7 +786,7 @@ DataSourceWidget::DataSourceWidget(QWidget* parent)
     _index = new KComboBox(this);
     _index->setToolTip(i18n("Vector index"));
     _index->setMinimumContentsLength(1);
-    _index->setSizeAdjustPolicy(QComboBox::AdjustToMinimumContentsLength);
+    _index->setSizeAdjustPolicy(QComboBox::AdjustToContents);
     layout->addWidget(_index, 0);
 
     connect(_object, SIGNAL(activated(int)),
@@ -826,7 +814,7 @@ void DataSourceWidget::addObjects(const QModelIndex& parent, const QString& inde
 
 StepCore::Object* DataSourceWidget::dataObject() const
 {
-    if(_object->currentIndex() < 0) return NULL;
+    if(_object->currentIndex() < 0) return nullptr;
     return _object->itemData(_object->currentIndex()).value<StepCore::Object*>();
 }
 
@@ -858,7 +846,7 @@ void DataSourceWidget::objectSelected(int index)
     _property->clear();
 
     const StepCore::Object* obj = _object->itemData(index).value<StepCore::Object*>();
-    if(obj != 0) {
+    if(obj != nullptr) {
         _property->setEnabled(true);
         for(int i=0; i<obj->metaObject()->propertyCount(); ++i) {
             const StepCore::MetaProperty* pr = obj->metaObject()->property(i);
@@ -881,10 +869,10 @@ void DataSourceWidget::propertySelected(int index)
     QString text = _property->itemData(index).toString();
     const StepCore::Object* obj = _object->itemData(_object->currentIndex())
                                                         .value<StepCore::Object*>();
-    const StepCore::MetaProperty* pr = obj ? obj->metaObject()->property(text) : 0;
+    const StepCore::MetaProperty* pr = obj ? obj->metaObject()->property(text) : nullptr;
 
     _index->clear();
-    if(pr != 0 && pr->userTypeId() == qMetaTypeId<StepCore::Vector2d>()) {
+    if(pr != nullptr && pr->userTypeId() == qMetaTypeId<StepCore::Vector2d>()) {
         _index->setEnabled(true);
         _index->addItem(QStringLiteral("0"));
         _index->addItem(QStringLiteral("1"));
@@ -897,7 +885,7 @@ void DataSourceWidget::propertySelected(int index)
 GraphGraphicsItem::GraphGraphicsItem(StepCore::Item* item, WorldModel* worldModel)
     : WidgetGraphicsItem(item, worldModel)
 {
-    Q_ASSERT(dynamic_cast<StepCore::Graph*>(_item) != NULL);
+    Q_ASSERT(dynamic_cast<StepCore::Graph*>(_item) != nullptr);
     setFlag(QGraphicsItem::ItemIsSelectable);
     setFlag(QGraphicsItem::ItemIsMovable);
     setAcceptHoverEvents(true);
@@ -1082,12 +1070,12 @@ void GraphGraphicsItem::worldDataChanged(bool dynamicOnly)
 
 void GraphMenuHandler::populateMenu(QMenu* menu, KActionCollection* actions)
 {
-    _confUi = 0;
-    _confDialog = 0;
+    _confUi = nullptr;
+    _confDialog = nullptr;
     _confChanged = false;
 
-    menu->addAction(QIcon::fromTheme(QStringLiteral("edit-clear")), i18n("Clear graph"), this, &GraphMenuHandler::clearGraph);
-    menu->addAction(QIcon::fromTheme(QStringLiteral("configure")), i18n("Configure graph..."), this, &GraphMenuHandler::configureGraph);
+    menu->addAction(QIcon::fromTheme(QStringLiteral("edit-clear")), i18n("Clear Graph"), this, &GraphMenuHandler::clearGraph);
+    menu->addAction(QIcon::fromTheme(QStringLiteral("configure")), i18n("Configure Graph..."), this, &GraphMenuHandler::configureGraph);
     menu->addSeparator();
     ItemMenuHandler::populateMenu(menu, actions);
 }
@@ -1105,7 +1093,7 @@ void GraphMenuHandler::configureGraph()
     _confChanged = false;
     _confDialog = new QDialog(); // XXX: parent?
     
-    _confDialog->setWindowTitle(i18n("Configure graph"));
+    _confDialog->setWindowTitle(i18nc("@title:window", "Configure Graph"));
     _buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok
 				      | QDialogButtonBox::Cancel
 				      | QDialogButtonBox::Apply);
@@ -1166,8 +1154,8 @@ void GraphMenuHandler::configureGraph()
 
     _confDialog->exec();
 
-    delete _confDialog; _confDialog = 0;
-    delete _confUi; _confUi = 0;
+    delete _confDialog; _confDialog = nullptr;
+    delete _confUi; _confUi = nullptr;
 }
 
 void GraphMenuHandler::confApply(QAbstractButton *button)
@@ -1243,7 +1231,7 @@ void GraphMenuHandler::clearGraph()
 MeterGraphicsItem::MeterGraphicsItem(StepCore::Item* item, WorldModel* worldModel)
     : WidgetGraphicsItem(item, worldModel)
 {
-    Q_ASSERT(dynamic_cast<StepCore::Meter*>(_item) != NULL);
+    Q_ASSERT(dynamic_cast<StepCore::Meter*>(_item) != nullptr);
     setFlag(QGraphicsItem::ItemIsSelectable);
     setFlag(QGraphicsItem::ItemIsMovable);
     setAcceptHoverEvents(true);
@@ -1310,11 +1298,11 @@ void MeterGraphicsItem::worldDataChanged(bool dynamicOnly)
 
 void MeterMenuHandler::populateMenu(QMenu* menu, KActionCollection* actions)
 {
-    _confUi = 0;
-    _confDialog = 0;
+    _confUi = nullptr;
+    _confDialog = nullptr;
     _confChanged = false;
 
-    menu->addAction(QIcon::fromTheme(QStringLiteral("configure")), i18n("Configure meter..."), this, &MeterMenuHandler::configureMeter);
+    menu->addAction(QIcon::fromTheme(QStringLiteral("configure")), i18n("Configure Meter..."), this, &MeterMenuHandler::configureMeter);
     menu->addSeparator();
     ItemMenuHandler::populateMenu(menu, actions);
 }
@@ -1332,7 +1320,7 @@ void MeterMenuHandler::configureMeter()
     _confChanged = false;
 
     _confDialog = new QDialog(); // XXX
-    _confDialog->setWindowTitle(i18n("Configure meter"));
+    _confDialog->setWindowTitle(i18nc("@title:window", "Configure Meter"));
     _buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok
 				      | QDialogButtonBox::Cancel
 				      | QDialogButtonBox::Apply);
@@ -1365,8 +1353,8 @@ void MeterMenuHandler::configureMeter()
 
     _confDialog->exec();
 
-    delete _confDialog; _confDialog = 0;
-    delete _confUi; _confUi = 0;
+    delete _confDialog; _confDialog = nullptr;
+    delete _confUi; _confUi = nullptr;
 }
 
 void MeterMenuHandler::confApply(QAbstractButton *button)
@@ -1406,7 +1394,7 @@ void MeterMenuHandler::confChanged()
 ControllerGraphicsItem::ControllerGraphicsItem(StepCore::Item* item, WorldModel* worldModel)
     : WidgetGraphicsItem(item, worldModel)
 {
-    Q_ASSERT(dynamic_cast<StepCore::Controller*>(_item) != NULL);
+    Q_ASSERT(dynamic_cast<StepCore::Controller*>(_item) != nullptr);
     setFlag(QGraphicsItem::ItemIsSelectable);
     setFlag(QGraphicsItem::ItemIsMovable);
     setAcceptHoverEvents(true);
@@ -1429,8 +1417,8 @@ ControllerGraphicsItem::ControllerGraphicsItem(StepCore::Item* item, WorldModel*
     layout->addWidget(_labelMax, 0, 2, 1, 1);
     layout->addWidget(_labelSource, 1, 0, 1, 3);
 
-    _incAction = new QAction(i18n("Increase value"), _widget);
-    _decAction = new QAction(i18n("Decrease value"), _widget);
+    _incAction = new QAction(i18n("Increase Value"), _widget);
+    _decAction = new QAction(i18n("Decrease Value"), _widget);
 
     connect(_incAction, &QAction::triggered, this, &ControllerGraphicsItem::incTriggered);
     connect(_decAction, &QAction::triggered, this, &ControllerGraphicsItem::decTriggered);
@@ -1622,14 +1610,14 @@ void ControllerGraphicsItem::sliderReleased()
 
 void ControllerMenuHandler::populateMenu(QMenu* menu, KActionCollection* actions)
 {
-    _confUi = 0;
-    _confDialog = 0;
+    _confUi = nullptr;
+    _confDialog = nullptr;
     _confChanged = false;
 
-    menu->addAction(QIcon::fromTheme(QStringLiteral("arrow-up")), i18n("Increase value"), this, &ControllerMenuHandler::incTriggered);
-    menu->addAction(QIcon::fromTheme(QStringLiteral("arrow-down")), i18n("Decrease value"), this, &ControllerMenuHandler::decTriggered);
+    menu->addAction(QIcon::fromTheme(QStringLiteral("arrow-up")), i18n("Increase Value"), this, &ControllerMenuHandler::incTriggered);
+    menu->addAction(QIcon::fromTheme(QStringLiteral("arrow-down")), i18n("Decrease Value"), this, &ControllerMenuHandler::decTriggered);
     menu->addSeparator();
-    menu->addAction(QIcon::fromTheme(QStringLiteral("configure")), i18n("Configure controller..."), this, &ControllerMenuHandler::configureController);
+    menu->addAction(QIcon::fromTheme(QStringLiteral("configure")), i18n("Configure Controller..."), this, &ControllerMenuHandler::configureController);
     menu->addSeparator();
     ItemMenuHandler::populateMenu(menu, actions);
 }
@@ -1647,7 +1635,7 @@ void ControllerMenuHandler::configureController()
     _confChanged = false;
     _confDialog = new QDialog(); // XXX
     
-    _confDialog->setWindowTitle(i18n("Configure controller"));
+    _confDialog->setWindowTitle(i18nc("@title:window", "Configure Controller"));
     _buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok
 				      | QDialogButtonBox::Cancel
 				      | QDialogButtonBox::Apply);
@@ -1703,8 +1691,8 @@ void ControllerMenuHandler::configureController()
 
     _confDialog->exec();
 
-    delete _confDialog; _confDialog = 0;
-    delete _confUi; _confUi = 0;
+    delete _confDialog; _confDialog = nullptr;
+    delete _confUi; _confUi = nullptr;
 }
 
 void ControllerMenuHandler::confApply(QAbstractButton *button)
@@ -1775,7 +1763,7 @@ void ControllerMenuHandler::incTriggered()
 TracerGraphicsItem::TracerGraphicsItem(StepCore::Item* item, WorldModel* worldModel)
     : StepGraphicsItem(item, worldModel), _moving(false), _movingDelta(0,0)
 {
-    Q_ASSERT(dynamic_cast<StepCore::Tracer*>(_item) != NULL);
+    Q_ASSERT(dynamic_cast<StepCore::Tracer*>(_item) != nullptr);
     setFlag(QGraphicsItem::ItemIsSelectable);
     setFlag(QGraphicsItem::ItemIsMovable);
     setZValue(HANDLER_ZVALUE);
@@ -1903,12 +1891,12 @@ void TracerGraphicsItem::mouseSetPos(const QPointF&, const QPointF& diff, Moving
 {
     static_cast<WorldScene*>(scene())->snapItem(vectorToPoint(tracer()->position()) + diff,
                 WorldScene::SnapRigidBody | WorldScene::SnapParticle |
-                WorldScene::SnapSetLocalPosition, 0, movingState, _item);
+                WorldScene::SnapSetLocalPosition, nullptr, movingState, _item);
 }
 
 void TracerMenuHandler::populateMenu(QMenu* menu, KActionCollection* actions)
 {
-    menu->addAction(QIcon::fromTheme(QStringLiteral("edit-clear")), i18n("Clear trace"), this, &TracerMenuHandler::clearTracer);
+    menu->addAction(QIcon::fromTheme(QStringLiteral("edit-clear")), i18n("Clear Trace"), this, &TracerMenuHandler::clearTracer);
     menu->addSeparator();
     ItemMenuHandler::populateMenu(menu, actions);
 }
